<?php
function bulk_author_creator_admin_page() {
    // Check user capabilities
    if (!current_user_can('create_users')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }

    // Handle form submission
    if (isset($_POST['submit_authors'])) {
        check_admin_referer('bulk_author_creator_nonce');
        
        $names = array_filter(
            array_map(
                'trim',
                explode("\n", sanitize_textarea_field($_POST['author_names']))
            )
        );

        if (!empty($names)) {
            $results = Bulk_Author_Creator::create_authors($names);
        }
    }
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        
        <?php if (isset($results)): ?>
            <div class="notice notice-success">
                <h3>Creation Results:</h3>
                <p>Successfully created: <?php echo count($results['success']); ?> authors</p>
                <p>Failed to create: <?php echo count($results['failed']); ?> authors</p>
                
                <?php if (!empty($results['success'])): ?>
                    <h4>Successfully created authors:</h4>
                    <ul>
                        <?php foreach ($results['success'] as $author): ?>
                            <li><?php echo esc_html($author['name']); ?> 
                                (<?php echo esc_html($author['username']); ?>) - 
                                <?php echo esc_html($author['email']); ?></li>
                        <?php endforeach; ?>
                    </ul>
                <?php endif; ?>

                <?php if (!empty($results['failed'])): ?>
                    <h4>Failed authors:</h4>
                    <ul>
                        <?php foreach ($results['failed'] as $failure): ?>
                            <li><?php echo esc_html($failure['name']); ?>: 
                                <?php echo esc_html($failure['error']); ?></li>
                        <?php endforeach; ?>
                    </ul>
                <?php endif; ?>
            </div>
        <?php endif; ?>

        <form method="post">
            <?php wp_nonce_field('bulk_author_creator_nonce'); ?>
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="author_names">Author Names</label>
                    </th>
                    <td>
                        <textarea name="author_names" id="author_names" rows="10" cols="50" 
                            class="large-text" placeholder="Enter one name per line"><?php 
                            echo isset($_POST['author_names']) ? esc_textarea($_POST['author_names']) : ''; 
                        ?></textarea>
                        <p class="description">Enter one author name per line</p>
                    </td>
                </tr>
            </table>
            <?php submit_button('Create Authors', 'primary', 'submit_authors'); ?>
        </form>
    </div>
    <?php
}